import java.util.ArrayList;
import java.util.Iterator;

/**
 * The database class provides a facility to store CD and DVD 
 * objects. A list of all CDs and DVDs can be printed to the
 * terminal.
 * 
 * This version does not save the data to disk.
 * 
 * @author Michael Kolling and David J. Barnes
 * @version 2002-05-02
 */
public class Database
{
    // add "books" here, and initialize in the constructor -- pld
    private ArrayList<Item> items;
    
    /**
     * Construct an empty Database.
     */
    public Database()
    {
        items = new ArrayList<Item>();
    }

    /**
     * Add an Item to the database.
     */
    public void addItem(Item theItem)
    {
        items.add(theItem);
    }

    /**
     * Print a list of all currently stored CDs and DVDs to the
     * text terminal.
     */
    public void list()
    {
        // print list of CDs
        for(Item theItem : items ) {
            theItem.print();
            System.out.println();   // empty line between items
        }
    }
    
    /**
     * The following should search all the Items for anything with a title
     * that contains the string "srchkey".
     * Items with a match are printed.
     * Make the comparisons case-insensitive by converting to lowercase.
     * -- pld
     */
    public void searchTitle (String srchkey) {
        srchkey = srchkey.toLowerCase();
        System.out.println("Searching for: " + srchkey);
        for (Item it : items) {
            String title = it.getTitle().toLowerCase();
            if (title.contains(srchkey) ) {
                it.print();
            }
        }   
        System.out.println("=========== done with search ============");
    }
    
     /**
     * The following should search all the Items for anything in either 
     * the title or the keywords() string (artist/director/etc) 
     * that contains the string srchkey. 
     * Make the comparisons case-insensitive by converting to lowercase.
     * -- pld
     */
    public void searchAll (String srchkey) {
        srchkey = srchkey.toLowerCase();
        // rest like above, except use title+keywords() instead of just title
    }
    
    /**
     * Add a few entries for demo purposes - pld
     */
    public void add_demo() {
        addItem (new CD("Blood Money", "Tom Waits", 14, 63));
        addItem (new CD("bad hair day", "Weird Al Yankovic", 12, 65));
        addItem (new CD("Songs in the Key of Life", "Stevie Wonder", 21, 120));
        addItem (new DVD("The Harder They Come", "Perry Henzell", "Jimmy Cliff", 104));
        addItem (new DVD("Brazil", "Terry Gilliam", "Pryce, Greist, Palin", 118));
        addItem (new DVD("Monty Python's Meaning of Life", "Terry Jones & Terry Gilliam", 
                "Jones, Cleese, Chapman, Idle, Palin, Gilliam", 90));
        addItem (new DVD("The Secret Life of Walter Mitty", "Mark Waters", 
                "Mike Myers", 110));
        addItem (new DVD("Life or Something Like It", "Stephen Herek", 
                "Angelina Jolie", 98));
        //addGame(new Game("Warcraft", "Blizzard", 1));
        //addBook(new Book("The Secret Life of Walter Mitty", "James Thurber"));
    }
}
